@@ -147,7 +147,7 @@ def load_metadata() -> FeatureCollection:
     """
     ensure_data_directories_exist()
     if os.path.exists("/tmp/input/data.json"):
-        with open("/tmp/input/data.json") as fp:
+        with open("/tmp/input/data.json", encoding="utf-8") as fp:
             data = json.loads(fp.read())
 
         features = []
@@ -166,7 +166,7 @@ def save_metadata(result: FeatureCollection):
         result: Output feature collection.
     """
     ensure_data_directories_exist()
-    with open("/tmp/output/data.json", "w") as fp:
+    with open("/tmp/output/data.json", "w", encoding="utf-8") as fp:
         fp.write(json.dumps(result))
 
 
