@@ -3,15 +3,17 @@ Utilities for handling geometry operations.
 """
 import copy
 import math
-from typing import Generator, List
+from typing import Generator, List, Callable
 
 import geojson
 import mercantile
+from mercantile import Tile
 import numpy as np
 import rasterio as rio
 from area import area
 from shapely.geometry import box, mapping, shape
 from shapely.validation import explain_validity
+from shapely.ops import unary_union
 
 from .exceptions import SupportedErrors, UP42Error
 from .logging import get_logger
@@ -89,7 +91,10 @@ def get_query_bbox(query: STACQuery) -> BoundingBox:
 
 
 def aoi_size_check(
-    query: STACQuery, min_sqkm: float = None, max_sqkm: float = None
+    query: STACQuery,
+    min_sqkm: float = None,
+    max_sqkm: float = None,
+    ignore_missing_geometry: bool = False,
 ) -> bool:
     """
     Checks if the query geometry is within set AOI size bounds.
@@ -98,20 +103,31 @@ def aoi_size_check(
         query: A STACQuery object.
         min_sqkm: The minimum size in square kilometers.
         max_sqkm: The maximum size in square kilometers.
+        ignore_missing_geometry: Return True even if the
+            STACQuery object does not include a geometry.
 
     Returns:
         Is the query within AOI size bounds.
+
+    Raises:
+        UP42Error: If query has no geometry and
+            ignore_missing_geometry is False (default).
     """
     valid = True
-    area_sqkm = area(query.geometry()) / (10 ** 6)
+    try:
+        geom = query.geometry()
+        area_sqkm = area(geom) / (10 ** 6)
 
-    if min_sqkm is not None:
-        if area_sqkm < min_sqkm:
-            valid = False
+        if min_sqkm is not None:
+            if area_sqkm < min_sqkm:
+                valid = False
 
-    if max_sqkm is not None:
-        if area_sqkm > max_sqkm:
-            valid = False
+        if max_sqkm is not None:
+            if area_sqkm > max_sqkm:
+                valid = False
+    except UP42Error:
+        if not ignore_missing_geometry:
+            raise
 
     return valid
 
@@ -257,3 +273,14 @@ def check_validity(query_geom: dict):
             SupportedErrors.INPUT_PARAMETERS_ERROR,
             f"Input geometry is not valid due to following reason: {explanation}",
         )
+
+
+def tiles_to_geom(tiles: List[Tile], func: Callable = mercantile):
+    """Apply unary_union function on the list of tiles.
+    Args:
+        tiles: List of tiles.
+        func: A callable used for working with tiles. By defauld it is mercantile. Any other custom
+              module can be used.
+    """
+    return_poly = unary_union([box(*tuple(func.bounds(tile))) for tile in tiles])
+    return return_poly
